\r grr
SET character_set_client = utf8;

-- ------------------------------------------------------------------------------------------------------------------------------------------
-- Uniquement si GRR est activé
-- ------------------------------------------------------------------------------------------------------------------------------------------
%if %%is_defined('activer_grr') and %%activer_grr == 'oui'

-- ------------------------------------------------------------------------------------------------------------------------------------------
-- Procédure et fonction d'ajout de colonne si elle n'existe pas
-- https://stackoverflow.com/questions/972922/add-column-to-mysql-table-if-it-does-not-exist
-- ------------------------------------------------------------------------------------------------------------------------------------------
DELIMITER $$

DROP PROCEDURE IF EXISTS addFieldIfNotExists 
$$
DROP FUNCTION IF EXISTS isFieldExisting 
$$

CREATE FUNCTION isFieldExisting (table_name_IN VARCHAR(100), field_name_IN VARCHAR(100)) 
RETURNS INT
RETURN (
    SELECT COUNT(COLUMN_NAME) 
    FROM INFORMATION_SCHEMA.columns 
    WHERE TABLE_SCHEMA = DATABASE() 
    AND TABLE_NAME = table_name_IN 
    AND COLUMN_NAME = field_name_IN
)
$$

CREATE PROCEDURE addFieldIfNotExists (
    IN table_name_IN VARCHAR(100)
    , IN field_name_IN VARCHAR(100)
    , IN field_definition_IN VARCHAR(100)
)
BEGIN

    -- http://javajon.blogspot.com/2012/10/mysql-alter-table-add-column-if-not.html

    SET @isFieldThere = isFieldExisting(table_name_IN, field_name_IN);
    IF (@isFieldThere = 0) THEN

        SET @ddl = CONCAT('ALTER TABLE ', table_name_IN);
        SET @ddl = CONCAT(@ddl, ' ', 'ADD COLUMN') ;
        SET @ddl = CONCAT(@ddl, ' ', field_name_IN);
        SET @ddl = CONCAT(@ddl, ' ', field_definition_IN);

        PREPARE stmt FROM @ddl;
        EXECUTE stmt;
        DEALLOCATE PREPARE stmt;

    END IF;

END;
$$
DELIMITER ;

-- -----------------------------------------------------------------------------------------------------------------------------------------
-- ------------- Migration 1.9.7e --> 2.2.2 ------------------------------------------------------------------------------------------------
-- -----------------------------------------------------------------------------------------------------------------------------------------

DROP PROCEDURE IF EXISTS 197to222;
DELIMITER |
CREATE PROCEDURE 197to222()
BEGIN
	DECLARE version VARCHAR(100);

	SELECT VALUE INTO version FROM grr_setting WHERE NAME='version';

	IF version < '2.2.2' THEN
        INSERT IGNORE INTO grr_setting (NAME, VALUE) VALUES ('default_css','default');

        -- Forcage du théme default 
        UPDATE grr_setting SET VALUE='default' WHERE NAME='default_css';
        UPDATE grr_utilisateurs SET default_style='' WHERE 1;

        -- Suppression du login adminsitrateur qui a pu être généré par l'installeur de Grr
        DELETE FROM grr_utilisateurs WHERE login='ADMINISTRATEUR';

		-- Mise à jour de la version applicative
		UPDATE grr_setting SET VALUE='2.2.2' WHERE NAME='version';

	END IF;
END|
DELIMITER ;

CALL 197to222();
DROP PROCEDURE 197to222;


-- -----------------------------------------------------------------------------------------------------------------------------------------
-- ------------- Migration 2.2.2 --> 3.2.0 -------------------------------------------------------------------------------------------------
-- -----------------------------------------------------------------------------------------------------------------------------------------

DROP PROCEDURE IF EXISTS 222to320;
DELIMITER |
CREATE PROCEDURE 222to320()
BEGIN
	DECLARE version VARCHAR(100);

	SELECT VALUE INTO version FROM grr_setting WHERE NAME='version';

	IF version < '3.2.0' THEN
        -- Mise à jour de structure de la table grr_entry
        CALL addFieldIfNotExists ('grr_entry', 'clef', 'INT(2) NOT NULL DEFAULT \'0\' AFTER jours');
        CALL addFieldIfNotExists ('grr_entry', 'courrier', 'INT(2) NOT NULL DEFAULT \'0\' AFTER clef');

        -- Mise à jour de structure de la table grr_log
        ALTER TABLE `grr_log` CHANGE `START` `START` DATETIME NOT NULL DEFAULT '1970-01-01 00:00:00', CHANGE `END` `END` DATETIME NOT NULL DEFAULT '1970-01-01 00:00:00';

        -- Mise à jour de structure de la table grr_repeat
        CALL addFieldIfNotExists ('grr_repeat', 'courrier', 'INT(2) NOT NULL DEFAULT \'0\' AFTER jours');

        -- Mise à jour de structure de la table grr_room
        CALL addFieldIfNotExists ('grr_room', 'active_cle', 'CHAR(1) NOT NULL DEFAULT \'Y\' AFTER active_ressource_empruntee');

        -- Forcage du théme default car les autres thèmes sont vraiment trop moches
        INSERT INTO grr_setting (NAME, VALUE) VALUES ('default_css','default') ON DUPLICATE KEY UPDATE `VALUE`='default';

        -- Nouvelles entrées de configuration
        INSERT IGNORE INTO grr_setting (NAME, VALUE) VALUES ('smtp port','25');
        INSERT IGNORE INTO grr_setting (NAME, VALUE) VALUES ('smtp_secure','');
        INSERT IGNORE INTO grr_setting (NAME, VALUE) VALUES ('menu_gauche','1');

        -- Remise à plat des dates dans les logs suite modification de la valeur par défaut
        UPDATE `grr_log` SET `START`= '1970-01-01 00:00:00' WHERE `START`= '0000-00-00 00:00:00';
        UPDATE `grr_log` SET `END`= '1970-01-01 00:00:00' WHERE `END`= '0000-00-00 00:00:00';

		-- Mise à jour de la version applicative
		UPDATE grr_setting SET VALUE='3.2.0' WHERE NAME='version';

	END IF;
END|
DELIMITER ;

CALL 222to320();
DROP PROCEDURE 222to320;

-- ------------------------------------------------------------------------------------------------------------------------------------------
-- ------------- Création admin secondaire --------------------------------------------------------------------------------------------------
-- ------------------------------------------------------------------------------------------------------------------------------------------
%if %%is_defined('activer_addadmin') and %%activer_addadmin == 'oui'

DROP PROCEDURE IF EXISTS AddAdminGrr;
delimiter |
CREATE PROCEDURE AddAdminGrr(_adminuser VARCHAR( 32 ))
BEGIN
    DECLARE ad_id INT DEFAULT 0;

    SELECT COUNT(*) INTO ad_id FROM grr_utilisateurs WHERE login=_adminuser;

    IF ad_id = 0 THEN
        INSERT IGNORE INTO `grr_utilisateurs` (`login`, `nom`, `prenom`, `password`, `email`, `statut`, `etat`, `default_site`, `default_area`, `default_room`, `default_style`, `default_list_type`, `default_language`, `source`) VALUES 
        ( _adminuser,'Envole','Administrateur','','','administrateur','actif',0,0,0,'','','','ext');
    END IF;

    UPDATE grr_utilisateurs SET statut = 'administrateur' WHERE login = _adminuser;

END|
DELIMITER ;

CALL AddAdminGrr('%%uid_addadmin');

%end if

-- Forcer la configuration sso
UPDATE grr_setting SET value='cas_envole' WHERE name='sso_statut';

-- ------------------------------------------------------------------------------------------------------------------------------------------
-- Suppression des procédures et fonctions en sortant
-- ------------------------------------------------------------------------------------------------------------------------------------------
DROP PROCEDURE IF EXISTS addFieldIfNotExists;
DROP FUNCTION IF EXISTS isFieldExisting;
DROP PROCEDURE IF EXISTS AddAdminGrr;

-- ------------------------------------------------------------------------------------------------------------------------------------------
-- Fin du si GRR est activé
-- ------------------------------------------------------------------------------------------------------------------------------------------
%end if
